// Plugins
import Components from 'unplugin-vue-components/vite'
import Vue from '@vitejs/plugin-vue'
import Vuetify, { transformAssetUrls } from 'vite-plugin-vuetify'
import ViteFonts from 'unplugin-fonts/vite'

// Utilities
import { defineConfig } from 'vite'
import { fileURLToPath, URL } from 'node:url'

import {resolve} from 'path';



// https://vitejs.dev/config/
export default defineConfig({
  plugins: [
    Vue({
      template: { transformAssetUrls }
    }),
    // https://github.com/vuetifyjs/vuetify-loader/tree/master/packages/vite-plugin#readme
    Vuetify(),
    Components(),
    ViteFonts({
      google: {
        families: [{
          name: 'Roboto',
          styles: 'wght@100;300;400;500;700;900',
        }],
      },
    }),
  ],
  define: { 'process.env': {} },
  resolve: {
    alias: {
      '@': fileURLToPath(new URL('./src', import.meta.url))
    },
    extensions: [
      '.js',
      '.json',
      '.jsx',
      '.mjs',
      '.ts',
      '.tsx',
      '.vue',
    ],
  },
  server: {
    port: 3000,
  },
  build: {
    rollupOptions: {
      input: {
        index: resolve(__dirname, 'index.html'),
        // home: resolve(__dirname, 'home.html'),
        space: resolve(__dirname, 'space.html'),
        main: resolve(__dirname, 'main.html'),
        lauched_games: resolve(__dirname, 'lauched_games.html'),
        audit_games: resolve(__dirname, 'audit_games.html'),
        my_recentgames: resolve(__dirname, 'my_recentgames.html'),
        score_ranking: resolve(__dirname, 'score_ranking.html'),
        // manage: resolve(__dirname, 'manage.html'),
        user_audit: resolve(__dirname, 'user_audit.html'),
        user_manage: resolve(__dirname, 'user_manage.html'),
        season_manage: resolve(__dirname, 'season_manage.html'),
        player_audit: resolve(__dirname, 'player_audit.html'),
        player_manage: resolve(__dirname, 'player_manage.html'),
        game_manage: resolve(__dirname, 'game_manage.html'),
        past_seasons: resolve(__dirname, 'past_seasons.html'),
        carousel_manage: resolve(__dirname, 'carousel_manage.html'),
      }
    },
  },
})
